@@ -1,10 +1,10 @@
-import time
 import json
 import errno
 import socket
 import logging
 
-from kuyruk.heartbeat import Heartbeat
+from monotonic import monotonic
+
 from kuyruk.exceptions import ResultTimeout, RemoteException
 
 logger = logging.getLogger(__name__)
@@ -14,15 +14,8 @@ class Result(object):
 
     def __init__(self, connection):
         self._connection = connection
-        self._heartbeat = Heartbeat(connection)
 
-    def _start_heartbeat(self):
-        self._heartbeat.start()
-
-    def _stop_heartbeat(self):
-        self._heartbeat.stop()
-
-    def _process_message(self, message):
+    def process_message(self, message):
         logger.debug("Reply received: %s", message.body)
         d = json.loads(message.body)
         self.result = d['result']
@@ -31,8 +24,7 @@ class Result(object):
     def wait(self, timeout):
         logger.debug("Waiting for task result")
 
-        start = time.time()
-        self._stop_heartbeat()
+        start = monotonic()
 
         while True:
             try:
@@ -48,7 +40,7 @@ class Result(object):
                 self._connection.heartbeat_tick()
                 self._connection.drain_events(timeout=1)
             except socket.timeout:
-                if time.time() - start > timeout:
+                if monotonic() - start > timeout:
                     raise ResultTimeout
             except socket.error as e:
                 if e.errno != errno.EINTR:
